==> nv-wp-aperson-basic-1.0.0.tgz: package/def.js <==


const ACT_CH2N = {
   创建记录:0,          //oper 业务员 | 管理员
   上传就绪:1,          //oper 业务员 | 管理员 
   审核结单:2,          //oper 业务员 | 管理员  填写  放行或禁行 原因
   删除工单:3,          //oper 管理员
}


const ACT_N2CH = {
    "0": "创建记录",
    "1": "上传就绪",
    "2": "审核结单",
    "3": "删除工单"
}

const ACT_EN2N = {
    creat:0,
    file_commit:1,
    audit:2,
    del:3
}

const ACT_N2EN = {
    "0": "creat",
    "1": "file_commit",
    "2": "audit",
    "3": "del"
}

const ACT_CH2EN = {
    "创建记录": "creat",
    "上传就绪": "file_commit",
    "审核结单": "audit",
    "删除工单": "del",
}

const ACT_EN2CH = {
    "creat": "创建记录",
    "file_commit": "上传就绪",
    "audit": "审核结单",
    "del": "删除工单"
}


////
const SEQ0_STATE    = {
    "creat"      :     "创建记录",
    "file_commit":     "上传就绪",
    "audit"      :     "审核结单",
}

const SEQ0_DEL_ACT = {
     "del": "删除工单"
}

const SEQ_1TOn_ACT = {
    "audit"      : "审核结单"
}

////


const DATA_EN2CH = {
    "sheet_id":"工单号",
    "seq"     :"序号",
    "oper": "操作人",
    "action": "操作类型",
    "reason": "禁行原因",
    "name": "姓名",
    "phone": "手机号",
    "idcard": "身份证号",
    "attr": "外来人员性质",
    "plate": "车牌号",
    "corp": "业务对接单位",
    "corp_contact_name": "业务对接单位联系人姓名",
    "corp_contact_phone": "业务对接单位联系人电话",
    "material": "核酸检测或隔离等管控材料",
    "health": "健康码截图",
    "travel": "行程卡截图",
    "signature": "签名",
    "all_files_ok": "所有文件上传就绪",
}


const DATA_CH2EN = {
  '工单号'                  : 'sheet_id',
  '序号'                    : 'seq',  
  '操作人'                  : 'oper',
  '操作类型'                : 'action',      //放行 禁行
  '禁行原因'                : 'reason',      //禁止原因     
  '姓名'                    : 'name',
  '手机号'                  : 'phone',
  '身份证号'                : 'idcard',
  '外来人员性质'            : 'attr',
  '车牌号'                  : 'plate',
  '业务对接单位'            : 'corp',
  '业务对接单位联系人姓名'  : 'corp_contact_name',
  '业务对接单位联系人电话'  : 'corp_contact_phone',
  '核酸检测或隔离等管控材料': 'material',
  '健康码截图'              : 'health',
  '行程卡截图'              : 'travel',
  '签名'                    : 'signature',
  '所有文件上传就绪'        : 'all_files_ok'  
}


const DATA_EN2DBTYP = {
  'sheet_id': 'char(36)',
  'seq': 'bigint',
  'oper'                    : 'text',  //操作员
  'action'                  : 'text',  //放行 禁行
  'reason'                  : 'text',  //禁止原因  
  'name'                    : 'text',
  'phone'                   : 'text',
  'idcard'                  : 'text',
  'attr'                    : 'text',
  'plate'                   : 'text',
  'corp'                    : 'text',
  'corp_contact_name'       : 'text',
  'corp_contact_phone'      : 'text',
  'material'                : 'json',  // [{id:,type:}....]
  'health'                  : 'json',  //  {id:,type:}
  'travel'                  : 'json',  //  {id:,type:}
  'signature'               : 'text',   //  签名
  'all_files_ok'            : 'bool',  //
}

const DATA_CH2DBTYP =   {
  '工单号'                  : 'char(36)',
  '序号'                    : 'bigint',
  '操作人'                  : 'text',
  '操作类型'                : 'text',      //放行 禁行
  '禁行原因'                : 'text',      //禁止原因     
  '姓名'                    : 'text',
  '手机号'                  : 'text',
  '身份证号'                : 'text',
  '外来人员性质'            : 'text',
  '车牌号'                  : 'text',
  '业务对接单位'            : 'text',
  '业务对接单位联系人姓名'  : 'text',
  '业务对接单位联系人电话'  : 'text',  
  '核酸检测或隔离等管控材料': 'json',
  '健康码截图'              : 'json',
  '行程卡截图'              : 'json',
  '签名'                    : 'text',
  '所有文件上传就绪'        : 'bool'
}

module.exports = {
    ACT_EN2N,
    ACT_N2EN,
    ACT_CH2N,
    ACT_N2CH,
    ACT_EN2CH,
    ACT_CH2EN,
    ////
    RATIO:100n,  //小数点
    DATA_EN2CH,
    DATA_CH2EN,
    DATA_EN2DBTYP,
    DATA_CH2DBTYP,
    ////
    SEQ0_STATE,
    SEQ0_DEL_ACT,
    SEQ_1TOn_ACT,
}

==> nv-wp-aperson-basic-1.0.1.tgz: package/def.js <==


const ACT_CH2N = {
   创建记录:0,          //oper 业务员 | 管理员
   上传就绪:1,          //oper 业务员 | 管理员 
   审核通过:2,          //oper 业务员 | 管理员  填写  放行或禁行 原因
   删除工单:3,          //oper 管理员
}


const ACT_N2CH = {
    "0": "创建记录",
    "1": "上传就绪",
    "2": "审核通过",
    "3": "删除工单"
}

const ACT_EN2N = {
    creat:0,
    file_commit:1,
    audit:2,
    del:3
}

const ACT_N2EN = {
    "0": "creat",
    "1": "file_commit",
    "2": "audit",
    "3": "del"
}

const ACT_CH2EN = {
    "创建记录": "creat",
    "上传就绪": "file_commit",
    "审核通过": "audit",
    "删除工单": "del",
}

const ACT_EN2CH = {
    "creat": "创建记录",
    "file_commit": "上传就绪",
    "audit": "审核通过",
    "del": "删除工单"
}


////
const SEQ0_STATE    = {
    "creat"      :     "创建记录",
    "file_commit":     "上传就绪",
    "audit"      :     "审核通过",
}

const SEQ0_DEL_ACT = {
     "del": "删除工单"
}

const SEQ_1TOn_ACT = {
    "audit"      : "审核通过"
}

////


const DATA_EN2CH = {
    "sheet_id":"工单号",
    "seq"     :"序号",
    "oper": "操作人",
    "action": "操作类型",
    "reason": "禁行原因",
    "name": "姓名",
    "phone": "手机号",
    "idcard": "身份证号",
    "attr": "外来人员性质",
    "plate": "车牌号",
    "corp": "业务对接单位",
    "corp_contact_name": "业务对接单位联系人姓名",
    "corp_contact_phone": "业务对接单位联系人电话",
    "material": "核酸检测或隔离等管控材料",
    "health": "健康码截图",
    "travel": "行程卡截图",
    "signature": "签名",
    "all_files_ok": "所有文件上传就绪",
}


const DATA_CH2EN = {
  '工单号'                  : 'sheet_id',
  '序号'                    : 'seq',  
  '操作人'                  : 'oper',
  '操作类型'                : 'action',      //放行 禁行
  '禁行原因'                : 'reason',      //禁止原因     
  '姓名'                    : 'name',
  '手机号'                  : 'phone',
  '身份证号'                : 'idcard',
  '外来人员性质'            : 'attr',
  '车牌号'                  : 'plate',
  '业务对接单位'            : 'corp',
  '业务对接单位联系人姓名'  : 'corp_contact_name',
  '业务对接单位联系人电话'  : 'corp_contact_phone',
  '核酸检测或隔离等管控材料': 'material',
  '健康码截图'              : 'health',
  '行程卡截图'              : 'travel',
  '签名'                    : 'signature',
  '所有文件上传就绪'        : 'all_files_ok'  
}


const DATA_EN2DBTYP = {
  'sheet_id': 'char(36)',
  'seq': 'bigint',
  'oper'                    : 'text',  //操作员
  'action'                  : 'text',  //放行 禁行
  'reason'                  : 'text',  //禁止原因  
  'name'                    : 'text',
  'phone'                   : 'text',
  'idcard'                  : 'text',
  'attr'                    : 'text',
  'plate'                   : 'text',
  'corp'                    : 'text',
  'corp_contact_name'       : 'text',
  'corp_contact_phone'      : 'text',
  'material'                : 'json',  // [{id:,type:}....]
  'health'                  : 'json',  //  {id:,type:}
  'travel'                  : 'json',  //  {id:,type:}
  'signature'               : 'text',   //  签名
  'all_files_ok'            : 'bool',  //
}

const DATA_CH2DBTYP =   {
  '工单号'                  : 'char(36)',
  '序号'                    : 'bigint',
  '操作人'                  : 'text',
  '操作类型'                : 'text',      //放行 禁行
  '禁行原因'                : 'text',      //禁止原因     
  '姓名'                    : 'text',
  '手机号'                  : 'text',
  '身份证号'                : 'text',
  '外来人员性质'            : 'text',
  '车牌号'                  : 'text',
  '业务对接单位'            : 'text',
  '业务对接单位联系人姓名'  : 'text',
  '业务对接单位联系人电话'  : 'text',  
  '核酸检测或隔离等管控材料': 'json',
  '健康码截图'              : 'json',
  '行程卡截图'              : 'json',
  '签名'                    : 'text',
  '所有文件上传就绪'        : 'bool'
}

module.exports = {
    ACT_EN2N,
    ACT_N2EN,
    ACT_CH2N,
    ACT_N2CH,
    ACT_EN2CH,
    ACT_CH2EN,
    ////
    RATIO:100n,  //小数点
    DATA_EN2CH,
    DATA_CH2EN,
    DATA_EN2DBTYP,
    DATA_CH2DBTYP,
    ////
    SEQ0_STATE,
    SEQ0_DEL_ACT,
    SEQ_1TOn_ACT,
}
